@@ -442,7 +442,7 @@ Indicate that the L<Rose::DB::Object>-derived object OBJECT is B<not> currently
 
 =head1 AUTHOR
 
-John C. Siracusa (siracusa@mindspring.com)
+John C. Siracusa (siracusa@gmail.com)
 
 =head1 COPYRIGHT
 
